__version__ = '0.0.6'
__title__ = 'ecs-mon'
__description__ = 'A CLI to easily monitor AWS ECS Service'
__url__ = 'https://github.com/modernix/ecs-mon'
__author__ = 'Ben Tran'
__author_email__ = 'ben.btran@gmail.com'
__license__ = 'MIT'
__keywords__ = ['aws-ecs', 'ecs service', 'monitor']
